@@ -47,7 +47,7 @@ class Bash(Processor):
         self.image = self._get_image_with_tag('bash', version)
         self.source = 'bash.sh'
         self.compile = ['bash', '-n', self.source]
-        self.judge = f'sh {self.source}'
+        self.judge = f'bash {self.source}'
 
 
 class Clang(Processor):
@@ -152,6 +152,16 @@ class OpenJDK(Processor):
         self.judge = 'java Main'
 
 
+class PHP(Processor):
+    'PHP'
+
+    def __init__(self, version=None):
+        self.image = self._get_image_with_tag('php', version)
+        self.source = 'index.php'
+        self.compile = ['php', '-l', self.source]
+        self.judge = f'php {self.source}'
+
+
 class PyPy(Processor):
     'PyPy'
 
@@ -172,3 +182,13 @@ class Python(Processor):
         self.source = '__init__.py'
         self.compile = ['python', '-m', 'compileall', '.']
         self.judge = f'python {self.source}'
+
+
+class Ruby(Processor):
+    'Ruby'
+
+    def __init__(self, version=None):
+        self.image = self._get_image_with_tag('ruby', version)
+        self.source = 'ruby.rb'
+        self.compile = ['ruby', '-wc', self.source]
+        self.judge = f'ruby {self.source}'
